@@ -1,4 +1,4 @@
-//$Id: button-canvas.cc,v 1.15 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: button-canvas.cc,v 1.17 2002/01/29 22:55:05 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,7 +26,9 @@ using namespace Guikachu::GUI::FormEditor;
 
 ButtonCanvasItem::ButtonCanvasItem (Widgets::Button    *widget_,
 				    Gnome::CanvasGroup *parent_group):
+    CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
+    ResizeableCanvasItem (widget_, parent_group),
     widget (widget_),
     group (0)
 {
@@ -222,7 +224,7 @@ void ButtonCanvasItem::update ()
     if (group)
 	delete group;
 
-    group = new Gnome::CanvasGroup (*parent_group, 0, 0);
+    group = new Gnome::CanvasGroup (*draw_group, 0, 0);
     
     int width = widget->get_display_width ();
     int height = widget->get_display_height ();
@@ -250,3 +252,12 @@ void ButtonCanvasItem::update ()
 
     set_canvas_item (group);
 }
+
+void ButtonCanvasItem::get_bounds (int &x1, int &y1,
+				   int &x2, int &y2)
+{
+    x1 = widget->x;
+    y1 = widget->y;
+    x2 = x1 + widget->get_display_width ();
+    y2 = y1 + widget->get_display_height ();
+}
