@@ -1,4 +1,4 @@
-//$Id: form-canvas.cc,v 1.3 2002/01/29 22:55:05 cactus Exp $ -*- c++ -*-
+//$Id: form-canvas.cc,v 1.4 2002/03/23 23:19:25 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,6 +41,7 @@ using namespace Guikachu::GUI::FormEditor;
 FormCanvasItem::FormCanvasItem (Widgets::Form      *form_widget,
 				Gnome::CanvasGroup *parent_group):
     CanvasItem (form_widget, parent_group),
+    ResizeableCanvasItem (form_widget, parent_group),
     res (form_widget->get_resource ()),
     group (0),
     background_item (0),
@@ -50,8 +51,9 @@ FormCanvasItem::FormCanvasItem (Widgets::Form      *form_widget,
 {
     using namespace SigC;
 
-    group = new Gnome::CanvasGroup (*draw_group, 0, 0);
-    widget_group = new Gnome::CanvasGroup (*group, 0, 0);
+    //group = new Gnome::CanvasGroup (*draw_group, 0, 0);
+    group = item_group;
+    widget_group = new Gnome::CanvasGroup (*item_group, 0, 0);
 
     // Popup menu
     std::list <Gnome::UI::Info> popup_menu_list;
@@ -104,7 +106,7 @@ void FormCanvasItem::draw_background ()
 void FormCanvasItem::draw_frame ()
 {
     delete frame_group;
-    frame_group = new Gnome::CanvasGroup (*group, 0, 0);
+    frame_group = new Gnome::CanvasGroup (*draw_group, 0, 0);
     
     Gnome::CanvasRect *frame_rect =
 	new Gnome::CanvasRect (*frame_group,
@@ -193,7 +195,7 @@ void FormCanvasItem::draw_frame_modal ()
 void FormCanvasItem::draw_title ()
 {
     delete title_group;
-    title_group = new Gnome::CanvasGroup (*group, 0, 0);
+    title_group = new Gnome::CanvasGroup (*draw_group, 0, 0);
 
     set_canvas_item (title_group);
     title_group->event.connect (SigC::retbind (
@@ -292,3 +294,13 @@ void FormCanvasItem::canvas_event_cb (GdkEvent *e)
 	(e->button.button == 3))
 	popup_menu.popup (e->button.button, e->button.time);
 }
+
+void FormCanvasItem::get_bounds (int &x1, int &y1,
+				 int &x2, int &y2)
+{
+    x1 = 0;
+    y1 = 0;
+
+    x2 = res->width;
+    y2 = res->height;
+}
