@@ -1,4 +1,4 @@
-//$Id: gadget.cc,v 1.6 2002/01/26 00:19:16 cactus Exp $ -*- c++ -*-
+//$Id: gadget.cc,v 1.7 2002/03/15 17:47:08 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,7 +27,7 @@ using namespace Guikachu::GUI::FormEditor;
 Gadget::Gadget (Resources::Form   *owner,
 		const std::string &id):
     Widget (owner, id),
-    Resizeable (changed),
+    ResizeableWidget (changed),
     editor (0),
     usable (changed, true)
 {
