@@ -1,4 +1,4 @@
-//$Id: gadget.h,v 1.5 2002/01/26 00:19:16 cactus Exp $ -*- c++ -*-
+//$Id: gadget.h,v 1.6 2002/03/15 17:47:08 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,7 +28,7 @@ namespace Guikachu
 }
 
 #include "widget.h"
-#include "resizeable.h"
+#include "resizeable-widget.h"
 
 #include "gadget-prop.h"
 
@@ -37,7 +37,7 @@ namespace Guikachu
     namespace Widgets
     {
 	class Gadget: public Widget,
-		      public Resizeable
+		      public ResizeableWidget
 	{
 	    GUI::FormEditor::GadgetProperties *editor;
 	    
