@@ -1,4 +1,4 @@
-//$Id: popup-trigger.cc,v 1.17 2002/01/26 00:19:16 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger.cc,v 1.18 2002/03/15 17:47:09 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,10 +27,11 @@ using namespace Guikachu::GUI::FormEditor;
 PopupTrigger::PopupTrigger (Resources::Form   *owner,
 			    const std::string &id):
     Widget (owner, id),
-    Resizeable (changed),
+    ResizeableWidget (changed),
     AutoWidth (changed),
     AutoHeight (changed),
     Textual (changed, id),
+    
     editor (0),
     list_id (changed, owner),
     usable (changed, true),
