@@ -1,4 +1,4 @@
-//$Id: selector-trigger-canvas.cc,v 1.18 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger-canvas.cc,v 1.21 2002/02/10 00:01:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,7 +26,9 @@ using namespace Guikachu::GUI::FormEditor;
 
 SelectorTriggerCanvasItem::SelectorTriggerCanvasItem (Widgets::SelectorTrigger *widget_,
 						      Gnome::CanvasGroup       *parent_group):
+    CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
+    ResizeableCanvasItem (widget_, parent_group),
     widget (widget_),
     group (0)
 {
@@ -38,7 +40,7 @@ void SelectorTriggerCanvasItem::update ()
     if (group)
 	delete group;
 
-    group = new Gnome::CanvasGroup (*parent_group, 0, 0);
+    group = new Gnome::CanvasGroup (*draw_group, 0, 0);
     
     int width = widget->get_display_width ();
     int height = widget->get_display_height ();
