@@ -1,4 +1,4 @@
-//$Id: widget-canvas.h,v 1.3 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
+//$Id: widget-canvas.h,v 1.5 2002/02/05 15:08:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,40 +42,37 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class WidgetCanvasItem: public CanvasItem
+	    class WidgetCanvasItem: public virtual CanvasItem
 	    {
 		Widget             *widget;
-		Gnome::CanvasItem  *selection_box;
 
 		Gtk::Menu           popup_menu;
 		
-	    protected:
-		bool selected;
-		
 	    protected:
 		WidgetCanvasItem (Widget             *widget,
-				  Gnome::CanvasGroup *parent_group);
-
-		void set_canvas_item (Gnome::CanvasGroup *item);
-		
+				  Gnome::CanvasGroup *parent_group);		
 	    public:
 		virtual ~WidgetCanvasItem ();
 
+	    protected:
+		// Selection
+		bool selected;
+		Gnome::CanvasItem *selection_box;
+		virtual Gnome::CanvasItem * create_selection_box ();
+
+	    public:
 		SigC::Signal0<void> menu_edit;
 		SigC::Signal0<void> menu_remove;
 		
 	    private:
+		void canvas_item_changed_cb ();
+
+		bool dirty;
+		void widget_changed_cb ();
+		void idle_cb           ();
+		
 		void widget_selected_cb (bool      selected);
 		void canvas_event_cb    (GdkEvent *event);
-
-	    protected:
-		virtual Gnome::CanvasItem * create_selection_box ();
-		virtual void get_bounds (int &x1, int &y1,
-					 int &x2, int &y2);
-
-	    public:
-		virtual bool is_within  (int x1, int y1,
-					 int x2, int y2);
 	    };
 	}
     }
