@@ -1,6 +1,6 @@
-//$Id: form-win-helpers.h,v 1.6 2001/12/19 22:03:59 cactus Exp $ -*- c++ -*-
+//$Id: form-win-helpers.h,v 1.8 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -25,12 +25,38 @@
 #include <gtk--/menu.h>
 #include <gtk--/label.h>
 
+#include <gnome--/canvas.h>
+#include <gnome--/canvas-rect.h>
+
 namespace Guikachu
 {
     namespace GUI
     {
 	namespace FormWindow_Helpers
 	{
+	    class CanvasSelectionWrapper: public SigC::Object
+	    {
+		Gnome::Canvas     &canvas;
+		Gnome::CanvasRect *rubber_box;
+		
+	    public:
+		CanvasSelectionWrapper (Gnome::Canvas &canvas);
+		~CanvasSelectionWrapper ();
+		
+		SigC::Signal4<void, int, int, int, int> selection;
+
+		void set_active (bool active);
+		
+	    private:
+		bool   dragging;
+		bool   active;
+		double selection_start_x, selection_start_y;
+		
+		void selection_begin (GdkEventButton *e);
+		void selection_drag  (GdkEventMotion *e);
+		void selection_end   (GdkEventButton *e);
+	    };
+	    
 	    class WidgetTreeItem: public Gtk::TreeItem
 	    {
 		Guikachu::Widget *widget;
