@@ -1,4 +1,4 @@
-//$Id: form-win.cc,v 1.48 2002/02/08 23:29:42 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.50 2002/02/23 15:44:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,6 +23,7 @@
 
 #include "form-editor/palette.h"
 
+#include <gtk--/main.h>
 #include <gtk--/treeitem.h>
 #include <gtk--/table.h>
 #include <gtk--/button.h>
@@ -59,6 +60,7 @@ FormWindow::FormWindow (Form *res_):
     zoom_entry (Gtk::wrap (GTK_SPIN_BUTTON (glade_xml_get_widget (gui, "form_zoom_entry")))),    
 
     edited_widget (0),
+    last_widget (0),
     canvas_overlay (0),
     palette_selection (Widgets::WIDGET_NONE)
 {
@@ -85,8 +87,8 @@ FormWindow::FormWindow (Form *res_):
     // Widget tree
     FormWindow_Helpers::TopTreeItem *item = new FormWindow_Helpers::TopTreeItem (res);
     item->show ();
-    item->activate.connect (slot (this, &FormWindow::form_select_cb));
-    item->menu_edit.connect (slot (this, &FormWindow::form_select_cb));
+    item->activate.connect (slot (this, &FormWindow::select_form));
+    item->menu_edit.connect (slot (this, &FormWindow::select_form));
     tree->add (*manage (item));
     top_treeitem = item;
 
@@ -143,7 +145,7 @@ void FormWindow::show ()
     window->get_window ().raise ();
     palette->show_all ();
     palette->get_window ().raise ();
-    
+
     if (edited_widget)
 	show_property_editor (edited_widget);
     else
@@ -178,15 +180,6 @@ void FormWindow::update ()
 
 }
 
-void FormWindow::edited_widget_changed ()
-{
-    g_return_if_fail (edited_widget != 0);
-
-    gchar *buffer = g_strdup_printf (_("Properties: %s"), edited_widget->id ().c_str ());
-    property_window->set_title (buffer);
-    g_free (buffer);
-}
-
 void FormWindow::recenter_canvas ()
 {
     float zoom_factor = canvas->get_pixels_per_unit ();
@@ -258,9 +251,9 @@ void FormWindow::widget_created_cb (Widget *widget)
     // Add tree item
     FormWindow_Helpers::WidgetTreeItem *tree_item = new FormWindow_Helpers::WidgetTreeItem (widget);
     tree_item->show ();
-    tree_item->activate.connect (bind (slot (this, &FormWindow::widget_select_cb), widget));
+    tree_item->activate.connect (bind (slot (this, &FormWindow::select_widget), widget));
     tree_item->menu_remove.connect (bind (slot (this, &FormWindow::widget_menu_remove_cb), widget));
-    tree_item->menu_edit.connect (bind (slot (this, &FormWindow::widget_select_cb), widget));
+    tree_item->menu_edit.connect (bind (slot (this, &FormWindow::select_widget), widget));
     
     tree->add (*tree_item);
     
@@ -270,7 +263,7 @@ void FormWindow::widget_created_cb (Widget *widget)
     canvas_item->clicked.connect (bind (slot (this, &FormWindow::widget_clicked_cb), widget));
     canvas_item->released.connect (bind (slot (this, &FormWindow::widget_released_cb), widget));
     canvas_item->menu_remove.connect (bind (slot (this, &FormWindow::widget_menu_remove_cb), widget));
-    canvas_item->menu_edit.connect (bind (slot (this, &FormWindow::widget_select_cb), widget));
+    canvas_item->menu_edit.connect (bind (slot (this, &FormWindow::select_widget), widget));
     
     canvas_item->drag_motion.connect (slot (this, &FormWindow::widget_drag_motion_cb));
     canvas_item->drag_end.connect (slot (this, &FormWindow::widget_drag_end_cb));
@@ -305,9 +298,9 @@ int FormWindow::canvas_overlay_cb (GdkEvent *event)
 
     if (event->button.button != 1)
 	return false;
-    
-    add_widget (int(event->button.x - res->x),
-		int(event->button.y - res->y));
+
+    add_widget (int (event->button.x - res->x),
+		int (event->button.y - res->y));
     
     palette->palette_applied ();
 
@@ -328,6 +321,15 @@ void FormWindow::palette_cb (Widgets::Type type)
     if (type == Widgets::WIDGET_NONE)
     {
 	window.set_cursor (0);
+
+	// Un-block rubber band selection from idle handler -- this
+	// way, it's done after the _after handler in the
+	// SelectionWrapper is run
+	Gtk::Main::idle.connect (SigC::retbind (SigC::bind (
+	    SigC::slot (selection_canvas,
+			&FormWindow_Helpers::CanvasSelectionWrapper::set_active),
+	    true), 0));
+	
 	return;
 
     } else {
@@ -353,151 +355,23 @@ void FormWindow::palette_cb (Widgets::Type type)
     canvas_overlay = new Gnome::CanvasPolygon (*canvas->root (), points);
     canvas_overlay->event.connect (slot (this, &FormWindow::canvas_overlay_cb));
     canvas_overlay->raise_to_top ();
+
+    selection_canvas->set_active (false);
 }
 
 void FormWindow::add_widget (int x, int y)
 {
+    g_return_if_fail (palette_selection != Widgets::WIDGET_NONE);
+    
     Widget *widget = res->create_widget (palette_selection);
 
     widget->x = x;
     widget->y = y;
 }
 
-void FormWindow::show_property_editor (Widget *widget)
-{
-    if (edited_widget == widget)
-    {
-	property_window->show_all ();
-	property_window->get_window ().raise ();
-	
-	return;
-    }
-
-    edited_widget = widget;
-    edited_widget_changed_conn.disconnect ();
-    edited_widget_changed_conn = edited_widget->changed.connect (
-	SigC::slot (this, &FormWindow::edited_widget_changed));
-    
-    Gtk::Widget *editor = widget->get_editor ();
-    
-    property_window->remove ();
-    property_window->add (*editor);
-    
-    property_window->show_all ();
-    property_window->get_window ().raise ();
-
-    edited_widget_changed ();
-}
-
-void FormWindow::show_form_property_editor ()
-{
-    edited_widget = 0;
-    edited_widget_changed_conn.disconnect ();
-    
-    Gtk::Widget *editor = form_widget->get_editor ();
-    
-    if (property_window->get_child () != editor)
-    {
-	property_window->remove ();
-	property_window->add (*editor);
-    }
-    
-    gchar *buffer = g_strdup_printf (_("Properties: %s"), res->id ().c_str());
-    property_window->set_title (buffer);
-    g_free (buffer);
-    
-    property_window->show_all ();
-    property_window->get_window ().raise ();
-}
-
-void FormWindow::selection_add (Widget *widget)
-{
-    selected_widgets.insert (widget);
-    widget->selected (true);
-}
-
-void FormWindow::selection_remove (Widget *widget)
-{
-#if 0
-    if (selected_widgets.find (widget) == selected_widgets.end ())
-	return;
-#endif
-    
-    selected_widgets.erase (widget);
-    widget->selected (false);
-}
-
-void FormWindow::selection_toggle (Widget *widget)
-{
-    if (selected_widgets.find (widget) == selected_widgets.end ())
-	selection_add (widget);
-    else
-	selection_remove (widget);
-}
-
-void FormWindow::selection_clear ()
-{
-    for (std::set<Widget*>::iterator i = selected_widgets.begin ();
-	 i != selected_widgets.end (); i++)
-	(*i)->selected (false);
-    
-    selected_widgets.clear ();
-}
-
-void FormWindow::form_select_cb ()
-{
-    bool add_to_selection;
-    
-    {
-	GdkModifierType modifiers;
-	int dummy;
-	
-	canvas->get_window ().get_pointer (dummy, dummy, modifiers);
-	add_to_selection = modifiers & GDK_CONTROL_MASK;
-    }
-
-    if (add_to_selection)
-	return;
-
-    selection_clear ();
-    
-    form_widget->selected (true);
-    top_treeitem->select ();
-   
-    show_form_property_editor ();
-}
-
-void FormWindow::widget_select_cb (Widget *widget)
-{
-    bool add_to_selection;
-    
-    {
-	GdkModifierType modifiers;
-	int dummy;
-	
-	canvas->get_window ().get_pointer (dummy, dummy, modifiers);
-	add_to_selection = modifiers & GDK_CONTROL_MASK;
-    }
-
-    top_treeitem->deselect ();
-    form_canvas_item->selected (false);
-    widget->request_edit ();
-    
-    if (!add_to_selection)
-    {
-	if (selected_widgets.find (widget) == selected_widgets.end ())
-	{
-	    selection_clear ();
-	    selection_add (widget);
-	}
-    } else {
-	selection_toggle (widget);
-    }
-}
-
 void FormWindow::form_clicked_cb ()
 {
-    form_select_cb ();
+    select_form ();
 
     // Block selection rubber box
     selection_canvas->set_active (false);
@@ -511,7 +385,15 @@ void FormWindow::form_released_cb ()
 
 void FormWindow::widget_clicked_cb (Widget *widget)
 {
-    widget_select_cb (widget);
+    if (last_widget != widget)
+    {
+	if (last_widget)
+	    last_widget->selected_last (false);
+	widget->selected_last (true);
+	last_widget = widget;
+    }
+    
+    select_widget (widget);
 
     // Block selection rubber box
     selection_canvas->set_active (false);
@@ -523,40 +405,6 @@ void FormWindow::widget_released_cb (Widget *widget)
     selection_canvas->set_active (true);
 }
 
-void FormWindow::selection_box_cb (int x1, int y1,
-				   int x2, int y2)
-{
-    x1 -= res->x;
-    x2 -= res->x;
-
-    y1 -= res->y;
-    y2 -= res->y;
-    
-    bool add_to_selection;
-    
-    {
-	GdkModifierType modifiers;
-	int dummy;
-	
-	canvas->get_window ().get_pointer (dummy, dummy, modifiers);
-	add_to_selection = modifiers & GDK_CONTROL_MASK;
-    }
-
-    if (!add_to_selection)
-	selection_clear ();
-
-    const std::set<Widget*>& widgets = res->get_widgets ();
-    for (std::set<Widget*>::const_iterator i = widgets.begin ();
-	 i != widgets.end (); i++)
-    {
-	FormEditor::WidgetCanvasItem *canvas_item =
-	    (*i)->get_canvas_item (form_canvas_item->get_widget_group ());
-	
-	if (canvas_item->is_within (x1, y1, x2, y2))
-	    selection_add (*i);
-    }
-}
-
 void FormWindow::widget_menu_remove_cb (Widget *widget)
 {
     g_return_if_fail (widget);
