@@ -1,4 +1,4 @@
-//$Id: mainwin.cc,v 1.23 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.cc,v 1.25 2002/02/10 14:11:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,11 +16,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include "mainwin.h"
-
 #include "config.h"
 #include <libgnome/libgnome.h>
 
+#include "mainwin.h"
+
 #include <gtk--/statusbar.h>
 #include <gtk--/scrolledwindow.h>
 
@@ -226,7 +226,7 @@ void GUI::MainWin::update_title ()
     if (filename != "")
 	title_buf = g_strdup_printf (_("Guikachu: %s"), g_basename (filename.c_str ()));
     else
-	title_buf = g_strdup_printf (_("Guikachu: %s"), "<none>");
+	title_buf = g_strdup_printf (_("Guikachu: %s"), _("<unnamed>"));
 	
     set_title (title_buf);
 
